@@ -226,7 +226,7 @@ def _get_property_value(component: UnicornView, property_name: str) -> Any:
 
 @timed
 def _call_method_name(
-    component: UnicornView, method_name: str, params: List[Any]
+    component: UnicornView, method_name: str, args: List[Any], kwargs: Dict[str, Any]
 ) -> Any:
     """
     Calls the method name with parameters.
@@ -234,14 +234,19 @@ def _call_method_name(
     Args:
         param component: Component to call method on.
         param method_name: Method name to call.
-        param params: List of arguments for the method.
+        param args: List of arguments for the method.
+        param kwargs: Dictionary of kwargs for the method.
     """
 
     if method_name is not None and hasattr(component, method_name):
         func = getattr(component, method_name)
 
-        if params:
-            return func(*params)
+        if args and kwargs:
+            return func(*args, **kwargs)
+        elif args:
+            return func(*args, **kwargs)
+        elif kwargs:
+            return func(**kwargs)
         else:
             return func()
 
@@ -361,8 +366,8 @@ def _process_component_request(
             call_method_name = payload.get("name", "")
             assert call_method_name, "Missing 'name' key for callMethod"
 
-            (method_name, params) = parse_call_method_name(call_method_name)
-            return_data = Return(method_name, params)
+            (method_name, args, kwargs) = parse_call_method_name(call_method_name)
+            return_data = Return(method_name, args, kwargs)
             setter_method = {}
 
             if "=" in call_method_name:
@@ -412,7 +417,7 @@ def _process_component_request(
                     component.errors = {}
                     is_reset_called = True
                 elif method_name == "$toggle":
-                    for property_name in params:
+                    for property_name in args:
                         property_value = _get_property_value(component, property_name)
                         property_value = not property_value
 
@@ -421,11 +426,11 @@ def _process_component_request(
                     # Handle the validate special action
                     validate_all_fields = True
                 else:
-                    component.calling(method_name, params)
+                    component.calling(method_name, args)
                     return_data.value = _call_method_name(
-                        component, method_name, params
+                        component, method_name, args, kwargs
                     )
-                    component.called(method_name, params)
+                    component.called(method_name, args)
         else:
             raise UnicornViewError(f"Unknown action_type '{action_type}'")
 
